@@ -43,7 +43,7 @@ class QStringList;
 
 namespace KTnef
 {
-
+class KTNEFWriterPrivateData;
 /**
  * @brief
  * Manages the writing of @acronym TNEF attachments.
@@ -148,7 +148,7 @@ public:
      * @return false if an invalid @acronym TNEF tag was specified by @p tag or
      * if there are no properties to write; else true.
      */
-    bool writeProperty(QDataStream &stream, int &bytes, int tag) const;
+    Q_REQUIRED_RESULT bool writeProperty(QDataStream &stream, int &bytes, int tag) const;
 
     /**
      * Writes the attachment to the #QIODevice specified by @p file.
@@ -156,7 +156,7 @@ public:
      * @param file is the #QIODevice to write.
      * @return true if the write was successful; otherwise false.
      */
-    bool writeFile(QIODevice &file) const;
+    Q_REQUIRED_RESULT bool writeFile(QIODevice &file) const;
 
     /**
      * Writes the attachment to the #QDataStream specified by @p stream.
@@ -164,7 +164,7 @@ public:
      * @param stream is the #QDataStream to write.
      * @return true if the write was successful; otherwise false.
      */
-    bool writeFile(QDataStream &stream) const;
+    Q_REQUIRED_RESULT bool writeFile(QDataStream &stream) const;
 
     /**
      * Sets the sender's @p name and @p email address.
@@ -289,8 +289,7 @@ public:
 
 private:
     //@cond PRIVATE
-    class PrivateData;
-    PrivateData *const d;
+    KTNEFWriterPrivateData *const d;
     //@endcond
 
     Q_DISABLE_COPY(KTNEFWriter)
